@@ -34,7 +34,12 @@ class CredentialsType(str, Enum):
     TOKEN = 'token'
     CALLBACK = 'interactive'
 
+    def __str__(self):
+        """Get the string representation."""
+        return self.value
 
+
+DEFAULT_GATEWAY_URL = 'https://api.waylay.io'
 DEFAULT_ACCOUNTS_URL = 'https://accounts-api.waylay.io'
 TokenString = str
 
@@ -42,13 +47,21 @@ TokenString = str
 class WaylayCredentials(abc.ABC):
     """Base class for the representation of credentials to the waylay platform."""
 
-    accounts_url: str
+    gateway_url: Optional[str] = None
     credentials_type: ClassVar[CredentialsType] = CredentialsType.CALLBACK
 
+    # legacy
+    accounts_url: Optional[str] = None
+
     @abc.abstractmethod
     def to_dict(self, obfuscate=True) -> Dict[str, Any]:
         """Convert the credentials to a json-serialisable representation."""
 
+    @abc.abstractproperty
+    def id(self) -> Optional[str]:
+        """Get the main identifier for this credential."""
+        return None
+
     def __repr__(self):
         """Show the implementing class and public information."""
         return f'<{self.__class__.__name__}({str(self)})>'
@@ -70,9 +83,10 @@ CredentialsCallback = Callable[[Optional[str]], WaylayCredentials]
 
 @dataclass(repr=False)
 class AccountsUrlMixin:
-    """Dataclass mixin for the 'accounts_url' property."""
+    """Dataclass mixin for the 'gateway_url' (legacy 'accounts_url') property."""
 
-    accounts_url: str = DEFAULT_ACCOUNTS_URL
+    gateway_url: Optional[str] = None
+    accounts_url: Optional[str] = None
 
 
 @dataclass(repr=False, init=False)
@@ -82,16 +96,29 @@ class ApiKeySecretMixin(AccountsUrlMixin):
     api_key: str = ''
     api_secret: str = ''
 
-    def __init__(self, api_key: str, api_secret: str, accounts_url: str = DEFAULT_ACCOUNTS_URL):
+    def __init__(
+        self, api_key: str, api_secret: str,
+        *, gateway_url: Optional[str] = None, accounts_url: Optional[str] = None
+    ):
         """Initialise with the api_key and api_secret."""
-        super().__init__(accounts_url=accounts_url)
+        super().__init__(gateway_url=gateway_url, accounts_url=accounts_url)
         self.api_key = api_key
         self.api_secret = api_secret
 
+    @property
+    def id(self) -> Optional[str]:
+        """Get the main identifier for this credential."""
+        return self.api_key
+
     @classmethod
-    def create(cls, api_key: str, api_secret: str, accounts_url: str = DEFAULT_ACCOUNTS_URL):
+    def create(
+        cls, api_key: str, api_secret: str,
+        *, gateway_url: Optional[str] = None, accounts_url: Optional[str] = None
+    ):
         """Create a client credentials object."""
-        return cls(api_key=api_key, api_secret=api_secret, accounts_url=accounts_url)
+        return cls(
+            api_key=api_key, api_secret=api_secret, gateway_url=gateway_url, accounts_url=accounts_url
+        )
 
     def to_dict(self, obfuscate=True):
         """Convert the credentials to a json-serialisable representation."""
@@ -99,6 +126,7 @@ class ApiKeySecretMixin(AccountsUrlMixin):
             type=self.credentials_type.value,
             api_key=self.api_key,
             api_secret='********' if obfuscate else self.api_secret,
+            gateway_url=self.gateway_url,
             accounts_url=self.accounts_url
         )
 
@@ -130,14 +158,11 @@ class NoCredentials(AccountsUrlMixin, WaylayCredentials):
 
     credentials_type: ClassVar[CredentialsType] = CredentialsType.CALLBACK
 
-    def __init__(self, accounts_url: str = DEFAULT_ACCOUNTS_URL):
-        """Create a Credentials object for postponed authentication."""
-        super().__init__(accounts_url=accounts_url)
-
     def to_dict(self, obfuscate=True):  # pylint: disable=unused-argument
         """Convert the credentials to a json-serialisable representation."""
         return dict(
-            type=self.credentials_type.value,
+            type=str(self.credentials_type),
+            gateway_url=self.gateway_url,
             accounts_url=self.accounts_url
         )
 
@@ -145,6 +170,11 @@ class NoCredentials(AccountsUrlMixin, WaylayCredentials):
         """Validate that these credentials are well-formed."""
         return True
 
+    @property
+    def id(self) -> Optional[str]:
+        """Get the main identifier for this credential."""
+        return None
+
 
 @dataclass(repr=False, init=False)
 class ClientCredentials(ApiKeySecretMixin, WaylayCredentials):
@@ -168,16 +198,29 @@ class TokenCredentials(AccountsUrlMixin, WaylayCredentials):
     credentials_type: ClassVar[CredentialsType] = CredentialsType.TOKEN
     token: TokenString = ''
 
-    def __init__(self, token: TokenString, accounts_url: str = DEFAULT_ACCOUNTS_URL):
+    def __init__(
+        self, token: TokenString,
+        *, gateway_url: Optional[str] = None, accounts_url: Optional[str] = None
+    ):
         """Create a TokenCredentials from a token string."""
-        super().__init__(accounts_url=accounts_url)
+        super().__init__(gateway_url=gateway_url, accounts_url=accounts_url)
         self.token = token
 
+    @property
+    def id(self) -> Optional[str]:
+        """Get the main identifier for this credential."""
+        try:
+            token = WaylayToken(self.token)
+            return f'[{token.domain}] {token.subject}'
+        except AuthError as exc:
+            return f'INVALID_TOKEN({exc})'
+
     def to_dict(self, obfuscate=True):
         """Get the credential attributes."""
         return dict(
-            type=self.credentials_type.value,
+            type=str(self.credentials_type),
             token='*********' if obfuscate else self.token,
+            gateway_url=self.gateway_url,
             accounts_url=self.accounts_url
         )
 
@@ -347,7 +390,10 @@ class WaylayTokenAuth(_http.Auth):
             initial_token = initial_token or credentials.token
 
         if initial_token:
-            self.current_token = self._create_and_validate_token(initial_token)
+            try:
+                self.current_token = self._create_and_validate_token(initial_token)
+            except AuthError:
+                pass
 
         self.credentials_callback = credentials_callback
 
@@ -376,7 +422,11 @@ class WaylayTokenAuth(_http.Auth):
         """Request a token."""
         if isinstance(self.credentials, NoCredentials):
             if self.credentials_callback is not None:
-                self.credentials = self.credentials_callback(self.credentials.accounts_url)
+                # TODO: where is this used? Clients need to update their
+                # definition of the callback to use gateway URL as argument.
+                self.credentials = self.credentials_callback(
+                    self.credentials.accounts_url or self.credentials.gateway_url
+                )
             else:
                 raise AuthError("No credentials or credentials_callback provided.")
 
@@ -392,22 +442,24 @@ class WaylayTokenAuth(_http.Auth):
             )
 
         if isinstance(self.credentials, ClientCredentials):
-            return _request_token_from_accounts(self.credentials)
+            return _request_token(self.credentials)
 
         raise AuthError(
             f"credentials of type {self.credentials.credentials_type} are not supported"
         )
 
 
-def _request_token_from_accounts(credentials: ClientCredentials) -> str:
-    token_url = f"{credentials.accounts_url}/tokens?grant_type=client_credentials"
+def _request_token(credentials: ClientCredentials) -> str:
+    token_url_prefix = credentials.accounts_url or f'{credentials.gateway_url}/accounts/v1'
+    token_url = f"{token_url_prefix}/tokens?grant_type=client_credentials"
     token_req = {
         'clientId': credentials.api_key,
         'clientSecret': credentials.api_secret,
     }
     try:
         token_resp = _http.post(url=token_url, json=token_req)
-        token_resp.raise_for_status()
+        if token_resp.status_code != 200:
+            raise AuthError(f'could not obtain waylay token: {token_resp.content!r} [{token_resp.status_code}]')
         token_resp_json = token_resp.json()
     except _http.HTTPError as exc:
         raise AuthError(f'could not obtain waylay token: {exc}') from exc
