@@ -8,13 +8,13 @@ import logging
 from argparse import ArgumentParser, Namespace, RawTextHelpFormatter
 from waylay.service.timeseries.tool import ResourceUpdateLevel
 
-from ._decorators import cli_exeption_decorator
-
 from waylay import WaylayClient
 from waylay.service.timeseries.parser.model import (
     SeriesSettings, ArchiveType, TimestampFormat, Metric, Resource
 )
 
+from ._decorators import cli_exeption_decorator
+
 LOG = logging.getLogger(__name__)
 
 SERIES_COMMANDS = [CMD_EXPORT, CMD_IMPORT] = ['export', 'import']
@@ -22,19 +22,29 @@ SERIES_COMMANDS = [CMD_EXPORT, CMD_IMPORT] = ['export', 'import']
 
 def init_series_parser(parser: ArgumentParser):
     """Initialize the parser for the 'series' command."""
-    series_cmd_parsers = parser.add_subparsers(
-        dest='series_cmd',
-        title='Series command',
-        **({'required': True} if sys.version_info > (3, 7) else {})  # type: ignore
-    )
+    if sys.version_info > (3, 7):
+        series_cmd_parsers = parser.add_subparsers(
+            help='Get or add timeseries data',
+            dest='series_cmd',
+            title='Series command',
+            required=True
+        )
+    else:
+        series_cmd_parsers = parser.add_subparsers(dest='series_cmd', title='Series command')
+
     init_series_export_parser(series_cmd_parsers.add_parser(
-        CMD_EXPORT, help='Export series to a local file',
+        CMD_EXPORT,
+        description='Export series to a local file',
+        help='Export series to a local file',
         formatter_class=RawTextHelpFormatter
     ))
     init_series_import_parser(series_cmd_parsers.add_parser(
-        CMD_IMPORT, help='Import series from a local file',
+        CMD_IMPORT,
+        description='Import series from a local file',
+        help='Import series from a local file',
         formatter_class=RawTextHelpFormatter
     ))
+    return parser
 
 
 def init_series_timestamp_parser(parser: ArgumentParser):
@@ -292,12 +302,15 @@ def init_series_import_timestamp_generation(parser: ArgumentParser):
     )
 
 
-def handle_series_cmd(client: WaylayClient, args: Namespace):
+def handle_series_cmd(client: WaylayClient, args: Namespace) -> bool:
     """Execute a 'series' command."""
     if args.series_cmd == CMD_EXPORT:
         handle_series_export_cmd(client, args)
+        return True
     elif args.series_cmd == CMD_IMPORT:
         handle_series_import_cmd(client, args)
+        return True
+    return False
 
 
 def convert_metrics(metrics_arg: List[str]) -> List[Metric]:
