@@ -4,37 +4,44 @@ from collections import defaultdict
 from typing import (
     Optional, TypeVar, List, Mapping, Type, Iterable, Dict
 )
-
-import pkg_resources
+import logging
+import sys
+if sys.version_info < (3, 10):
+    from importlib_metadata import entry_points
+else:
+    from importlib.metadata import entry_points
 
 from .service import (
     WaylayService,
+    WaylayRESTService,
     WaylayServiceContext,
-    AnalyticsService,
     ByomlService,
     TimeSeriesService,
-    ApiService,
+    ResourcesService,
     StorageService,
     UtilService,
     ETLService,
     DataService,
+    QueriesService,
     SERVICES
 )
+
+from .service.analytics import AnalyticsServiceLegacy
 from .exceptions import ConfigError
 
 from .config import (
     WaylayConfig,
-    DEFAULT_PROFILE
+    TenantSettings,
+    DEFAULT_PROFILE,
+    SERVICE_KEY_GATEWAY,
+    SERVICE_KEY_ACCOUNTS
 )
 from .auth import (
     WaylayCredentials,
     ClientCredentials,
     TokenCredentials,
-    DEFAULT_ACCOUNTS_URL
 )
 
-import logging
-
 S = TypeVar('S', bound=WaylayService)
 logger = logging.getLogger(__name__)
 
@@ -42,47 +49,62 @@ logger = logging.getLogger(__name__)
 class WaylayClient():
     """REST client for the Waylay Platform."""
 
-    analytics: AnalyticsService
+    analytics: AnalyticsServiceLegacy = AnalyticsServiceLegacy()
     byoml: ByomlService
     config: WaylayConfig
     timeseries: TimeSeriesService
-    api: ApiService
+    resources: ResourcesService
     storage: StorageService
     util: UtilService
     etl: ETLService
     data: DataService
+    queries: QueriesService
 
     @classmethod
     def from_profile(
         cls, profile: str = DEFAULT_PROFILE,
-        interactive=True, accounts_url=DEFAULT_ACCOUNTS_URL
+        *, interactive=True, gateway_url=None
     ):
         """Create a WaylayClient named profile.
 
         Uses credentials from environment variables or a locally stored configuration.
         """
-        return cls(WaylayConfig.load(profile, interactive=interactive, accounts_url=accounts_url))
+        return cls(WaylayConfig.load(
+            profile, interactive=interactive, gateway_url=gateway_url
+        ))
 
     @classmethod
     def from_client_credentials(
-        cls, api_key: str, api_secret: str, accounts_url: str = DEFAULT_ACCOUNTS_URL
+        cls, api_key: str, api_secret: str, *,
+        gateway_url=None, accounts_url=None,
+        settings: TenantSettings = None
     ):
         """Create a WaylayClient using the given client credentials."""
-        return cls.from_credentials(ClientCredentials(api_key, api_secret, accounts_url))
+        credentials = ClientCredentials(
+            api_key, api_secret, **_auth_urls(gateway_url, accounts_url, settings)
+        )
+        return cls.from_credentials(credentials, settings=settings)
 
     @classmethod
     def from_token(
-        cls, token_string: str, accounts_url: str = DEFAULT_ACCOUNTS_URL
+        cls, token_string: str, *,
+        gateway_url=None, accounts_url=None, settings: TenantSettings = None
     ):
         """Create a WaylayClient using a waylay token."""
-        return cls.from_credentials(TokenCredentials(token_string, accounts_url))
+        credentials = TokenCredentials(
+            token_string, **_auth_urls(gateway_url, accounts_url, settings)
+        )
+        return cls.from_credentials(credentials, settings=settings)
 
     @classmethod
     def from_credentials(
-        cls, credentials: WaylayCredentials
+        cls, credentials: WaylayCredentials, settings: TenantSettings = None
     ):
         """Create a WaylayClient using the given client credentials."""
-        return cls(WaylayConfig(credentials))
+        return cls(WaylayConfig(
+            credentials,
+            settings=settings
+        ))
 
     def __init__(self, config: WaylayConfig):
         """Create a WaylayConfig instance."""
@@ -107,8 +129,11 @@ class WaylayClient():
             srv.configure(self.config, context=self.service_context)
 
     def list_root_urls(self) -> Mapping[str, Optional[str]]:
-        """List the currently configured root url for each of the registered services."""
-        return {srv.config_key: srv.get_root_url() for srv in self._services}
+        """List the currently configured root url for each of the registered REST services."""
+        return {
+            srv.config_key: srv.get_root_url()
+            for srv in self._services if isinstance(srv, WaylayRESTService)
+        }
 
     def __repr__(self):
         """Get a technical string representation of this instance."""
@@ -123,15 +148,16 @@ class WaylayClient():
         """Load all services that are registered with the `waylay_services` entry point."""
         registered_service_classes = [
             srv_class
-            for entry_point in pkg_resources.iter_entry_points('waylay_services')
+            for entry_point in entry_points(group='waylay_services')
             for srv_class in entry_point.load()
         ]
         if not registered_service_classes:
             logger.warning(
-                f"The package {__package__} "
+                "The package %s "
                 "seems not to be installed properly. "
                 "If it was installed during this runtime session, "
-                "please restart the runtime before continuing."
+                "please restart the runtime before continuing.",
+                __package__
             )
             registered_service_classes = SERVICES
         self.register_service(*registered_service_classes)
@@ -198,3 +224,10 @@ class WaylayClient():
         Implements the `WaylayServiceContext.list` protocol.
         """
         return list(self._services)
+
+
+def _auth_urls(gateway_url=None, accounts_url=None, settings: TenantSettings = None):
+    if settings:
+        gateway_url = gateway_url or settings.get(SERVICE_KEY_GATEWAY)
+        accounts_url = accounts_url or settings.get(SERVICE_KEY_ACCOUNTS)
+    return {'gateway_url': gateway_url, 'accounts_url': accounts_url}
