@@ -1,23 +1,23 @@
 """Waylay Rest Services."""
 
-from ._base import WaylayService, WaylayResource, WaylayServiceContext
+from ._base import WaylayRESTService, WaylayResource, WaylayServiceContext, WaylayService, WaylayAction
 from . import _decorators as decorators
 
-from .analytics import AnalyticsService
 from .byoml import ByomlService
 from .timeseries import TimeSeriesService
-from .api import ApiService
+from .resources import ResourcesService
 from .storage import StorageService
 from .util import UtilService
 from .etl import ETLService
 from .data import DataService
+from .queries import QueriesService
 
 
 SERVICES = [
-    AnalyticsService,
     ByomlService,
     TimeSeriesService,
-    ApiService,
+    QueriesService,
+    ResourcesService,
     StorageService,
     UtilService,
     ETLService,
