@@ -13,7 +13,7 @@ class ByomlActionError(RestResponseError):
 
     @property
     def message(self):
-        """Get the main user error returned by an analytics error response."""
+        """Get the main user error returned by a byoml error response."""
         return self._get_from_body('error', super().message)
 
 
