@@ -1,7 +1,7 @@
 
-"""REST client for the Waylay Time Series Analytics Service."""
+"""REST client for the Waylay Byoml Service."""
 
-from .._base import WaylayService
+from .._base import WaylayRESTService
 
 from .model import ModelResource
 from .runtime import RuntimeResource
@@ -9,12 +9,12 @@ from .framework import FrameworkResource
 from .about import AboutResource
 
 
-class ByomlService(WaylayService):
+class ByomlService(WaylayRESTService):
     """REST client for the Waylay BYOML Service."""
 
     service_key = 'byoml'
     config_key = 'byoml'
-    default_root_url = 'https://byoml.waylay.io'
+    gateway_root_path = '/ml/v1'
 
     resource_definitions = {
         'model': ModelResource,
