@@ -8,9 +8,9 @@ from typing import (
 )
 import json
 import pandas as pd
-import numpy as np
 import logging
 
+from waylay.service import WaylayRESTService
 from .._base import WaylayResource
 from .._decorators import (
     return_body_decorator,
@@ -42,6 +42,23 @@ DEFAULT_MODEL_UPLOAD_TIMEOUT = 120
 LOG_SERVER_TIMING = logging.getLogger(__name__ + '.server-timing')
 byoml_server_timing_decorator = log_server_timing_decorator(LOG_SERVER_TIMING, logging.INFO)
 
+MODEL_NAME_ARG = {
+    'name': 'model_name',
+    'type': 'str',
+    'description': 'name for the model',
+    'example': 'my_prediction_model_001'
+}
+MODEL_RESULT = {
+    'name': 'model',
+    'type': 'Dict',
+    'description': 'A representation of the model deployment.'
+}
+MODEL_INFERENCE_RESULT = {
+    'name': 'results',
+    'type': 'List',
+    'description': 'The results of a model inference, normally a list of list of numerical data.'
+}
+
 
 def _input_data_as_list(input_data):
     if isinstance(input_data, list):
@@ -103,7 +120,8 @@ def _execute_model_decorators(response_key: str) -> List[Callable]:
         model_execution_request_decorator,
         return_path_decorator(
             [response_key],
-            default_response_constructor=np.array
+            default_response_constructor=None,
+            response_constructor_advice="Use 'np.array' to return a numpy array, 'pd.DataFrame' for a pandas dataframe."
         )
     ]
 
@@ -111,14 +129,24 @@ def _execute_model_decorators(response_key: str) -> List[Callable]:
 class ModelResource(WaylayResource):
     """REST Resource for the 'model' entity of the 'byoml' service."""
 
+    service: WaylayRESTService
+
     link_roots = {
-        'doc': '${doc_url}/api/byoml/?id='
+        'doc': '${doc_url}/api/byoml/?id=',
+        'apidoc': '${apidoc_url}/byoml.html'
     }
 
     actions = {
         'list': {
             'method': 'GET',
             'url': '/models',
+            'returns': [
+                {
+                    'name': 'models',
+                    'type': 'List[Dict]',
+                    'description': 'A list of metadata objects for available models'
+                }
+            ],
             'decorators': [
                 byoml_server_timing_decorator,
                 byoml_exception_decorator,
@@ -126,7 +154,8 @@ class ModelResource(WaylayResource):
             ],
             'description': 'List the metadata of the deployed <em>BYOML Models</em>',
             'links': {
-                'doc': 'overview-of-the-api'
+                'doc': 'overview-of-the-api',
+                'apidoc': '',
             },
         },
         'list_names': {
@@ -137,9 +166,17 @@ class ModelResource(WaylayResource):
                 byoml_exception_decorator,
                 return_path_decorator(['available_models', 'name'])
             ],
+            'returns': [
+                {
+                    'name': 'model_names',
+                    'type': 'List[str]',
+                    'description': 'A list of names of deployed models.'
+                }
+            ],
             'description': 'List the names of deployed <em>BYOML Models</em>',
             'links': {
-                'doc': 'overview-of-the-api'
+                'doc': 'overview-of-the-api',
+                'apidoc': '',
             },
         },
         '_create': {
@@ -155,15 +192,18 @@ class ModelResource(WaylayResource):
             'description': (
                 'Build and create a new <em>BYOML Model</em> as specified in the request'
             ),
-            'name': 'upload',
             'links': {
-                'doc': 'how-to-upload-your-model'
+                'doc': 'how-to-upload-your-model',
+                'apidoc': '',
             },
         },
+        'upload': {
+            'wrapped_actions': ['_create']
+        },
         '_replace': {
             'method': 'PUT',
             'url': '/models/{}',
-            'name': 'replace',
+            'arguments': [MODEL_NAME_ARG],
             'decorators': [
                 byoml_server_timing_decorator,
                 byoml_exception_decorator,
@@ -172,12 +212,18 @@ class ModelResource(WaylayResource):
             ],
             'description': 'Build and replace the named <em>BYOML Model</em>',
             'links': {
-                'doc': 'overwriting-a-model'
+                'doc': 'overwriting-a-model',
+                'apidoc': '',
             },
         },
+        'replace': {
+            'wrapped_actions': ['_replace']
+        },
         'get': {
             'method': 'GET',
             'url': '/models/{}',
+            'arguments': [MODEL_NAME_ARG],
+            'returns': [MODEL_RESULT],
             'decorators': [
                 byoml_server_timing_decorator,
                 byoml_exception_decorator,
@@ -187,12 +233,23 @@ class ModelResource(WaylayResource):
             ],
             'description': 'Fetch the metadata of the named <em>BYOML Model</em>',
             'links': {
-                'doc': 'checking-out-your-model'
+                'doc': 'checking-out-your-model',
+                'apidoc': '',
             },
         },
         'update': {
             'method': 'PATCH',
             'url': '/models/{}',
+            'arguments': [
+                MODEL_NAME_ARG,
+                {
+                    'name': 'body',
+                    'type': 'Dict[str,str]',
+                    'description': 'metadata attributes for the model',
+                    'examples': ['{"description":"Updated"}']
+                }
+            ],
+            'returns': [MODEL_RESULT],
             'decorators': [
                 byoml_server_timing_decorator,
                 byoml_exception_decorator,
@@ -201,28 +258,42 @@ class ModelResource(WaylayResource):
             ],
             'description': (
                 'Update the metadata of the named <em>BYOML Model</em>.\n'
-                'Only metadata attributes can be modified.\n'
-                '    model.update("my_model", body={"description":"Updated"})'
+                'Only metadata attributes can be modified.'
             ),
             'links': {
-                'doc': 'update-metadata-for-a-model'
-            },
-        },
-        'get_content': {
-            'method': 'GET',
-            'url': '/models/{}/content',
-            'decorators': [
-                byoml_server_timing_decorator,
-                byoml_exception_decorator
-            ],
-            'description': 'Fetch the content of the named <em>BYOML Model</em>',
-            'links': {
-                'doc': 'checking-out-your-model'
+                'doc': 'update-metadata-for-a-model',
+                'apidoc': '',
             },
         },
+        # ## not yet supported on plug-registry
+        # 'get_content': {
+        #     'method': 'GET',
+        #     'url': '/models/{}/content',
+        #     'arguments': [
+        #         MODEL_NAME_ARG
+        #     ],
+        #     'decorators': [
+        #         byoml_server_timing_decorator,
+        #         byoml_exception_decorator
+        #     ],
+        #     'description': 'Fetch the content of the named <em>BYOML Model</em>',
+        #     'links': {
+        #         'doc': 'checking-out-your-model'
+        #     },
+        # },
         'examples': {
             'method': 'GET',
             'url': '/models/{}/examples',
+            'arguments': [
+                MODEL_NAME_ARG
+            ],
+            'returns': [
+                {
+                    'name': 'examples',
+                    'type': 'List[Dict]',
+                    'description': 'A list of examples for the model'
+                }
+            ],
             'decorators': [
                 byoml_server_timing_decorator,
                 byoml_exception_decorator,
@@ -233,45 +304,56 @@ class ModelResource(WaylayResource):
                 'Fetch the <em>example request input</em> of the named <em>BYOML Model</em>'
             ),
             'links': {
-                'doc': 'example-input'
+                'doc': 'example-input',
+                'apidoc': '',
             },
         },
         'predict': {
             'method': 'POST',
             'url': '/models/{}/predict',
+            'arguments': [MODEL_NAME_ARG],
+            'returns': [MODEL_INFERENCE_RESULT],
             'decorators': _execute_model_decorators('predictions'),
             'description': (
                 'Execute the <em>predict</em> capability of the named <em>BYOML Model</em>'
             ),
             'links': {
-                'doc': 'predictions'
+                'doc': 'predictions',
+                'apidoc': '',
             },
         },
         'regress': {
             'method': 'POST',
             'url': '/models/{}/regress',
+            'arguments': [MODEL_NAME_ARG],
+            'returns': [MODEL_INFERENCE_RESULT],
             'decorators': _execute_model_decorators('result'),
             'description': (
                 'Execute the <em>regress</em> capability of the named  <em>BYOML Model</em>'
             ),
             'links': {
-                'doc': 'predictions'
+                'doc': 'predictions',
+                'apidoc': '',
             },
         },
         'classify': {
             'method': 'POST',
             'url': '/models/{}/classify',
+            'arguments': [MODEL_NAME_ARG],
+            'returns': [MODEL_INFERENCE_RESULT],
             'decorators': _execute_model_decorators('result'),
             'description': (
                 'Execute the <em>classification</em> capability of the named <em>BYOML Model</em>'
             ),
             'links': {
-                'doc': 'predictions'
+                'doc': 'predictions',
+                'apidoc': '',
             },
         },
         'remove': {
             'method': 'DELETE',
             'url': '/models/{}',
+            'arguments': [MODEL_NAME_ARG],
             'decorators': [
                 byoml_server_timing_decorator,
                 byoml_exception_decorator,
@@ -279,7 +361,8 @@ class ModelResource(WaylayResource):
             ],
             'description': 'Remove the named <em>BYOML Model</em>',
             'links': {
-                'doc': 'deleting-a-model'
+                'doc': 'deleting-a-model',
+                'apidoc': '',
             },
         },
     }
@@ -365,28 +448,28 @@ class ModelResource(WaylayResource):
     ) -> Any:
         """Upload a new machine learning model with given name, framework and description.
 
-        Parameters:
-            model_name      The name of the model.
-            trained_model   The model object (will be serialised to an zip archive before upload),
-                            or a file path to the serialized model file or folder.
-            framework       One of the supported frameworks (default 'sklearn').
-            framework_version
-                            A supported framework version, (default `None`,
-                            which selects the default server side)
-            metadata       User modifiable metadata. Standardised ones are:
-                            * 'description' A description of the model.
-                            * 'author' The attributed author of the model.
-                            * 'title' Used as display title in user interfaces.
-            description     Description of the model. (Deprecated: prefer `metadata.description`)
-            requirements_file
-                            A file containing custom python requirements (above that of the framework)
-            requirements    Custom python requirements (above those of the framework).
-                            Only one of 'requirements' and 'requirements_file' can be specified.
-            lib             A file or folder with custom packages that can be referred to in
-                            the requirements file as 'lib/<custom-requirement>'
-            work_dir        Optional location of the working directory used to serialize the model.
-                            If not specified, a temporary directory is used.
-            (other args)    Passed onto the underlying 'POST /model/{name}' request
+Arguments:
+    model_name      The name of the model.
+    trained_model   The model object (will be serialised to an zip archive before upload),
+                    or a file path to the serialized model file or folder.
+    framework       One of the supported frameworks (default 'sklearn').
+    framework_version
+                    A supported framework version, (default `None`,
+                    which selects the default server side)
+    metadata       User modifiable metadata. Standardised ones are:
+                    * 'description' A description of the model.
+                    * 'author' The attributed author of the model.
+                    * 'title' Used as display title in user interfaces.
+    description     Description of the model. (Deprecated: prefer `metadata.description`)
+    requirements_file
+                    A file containing custom python requirements (above that of the framework)
+    requirements    Custom python requirements (above those of the framework).
+                    Only one of 'requirements' and 'requirements_file' can be specified.
+    lib             A file or folder with custom packages that can be referred to in
+                    the requirements file as 'lib/<custom-requirement>'
+    work_dir        Optional location of the working directory used to serialize the model.
+                    If not specified, a temporary directory is used.
+    (other args)    Passed onto the underlying REST request
         """
         if requirements or requirements_file or lib:
             # use the new plug format upload (openfaas only)
@@ -434,21 +517,21 @@ class ModelResource(WaylayResource):
     ) -> Any:
         """Replace a machine learning model with given name, framework and description.
 
-        Parameters:
-            model_name      The name of the model.
-            trained_model   The model object (will be serialised to an zip archive before upload).
-            framework       One of the supported frameworks (default 'sklearn').
-            framework_version
-                            A supported framework version, (default `None`,
-                            which selects the default server side)
-            metadata       User modifiable metadata. Standardised ones are:
-                            * 'description' A description of the model.
-                            * 'author' The attributed author of the model.
-                            * 'title' Used as display title in user interfaces.
-            description     Description of the model. (Deprecated: prefer `metadata.description`)
-            work_dir        Optional location of the working directory used to serialize the model.
-                            If not specified, a temporary directory is used.
-            (other)         Passed onto the underlying 'PUT /model/{name}' request.
+Arguments:
+    model_name      The name of the model.
+    trained_model   The model object (will be serialised to an zip archive before upload).
+    framework       One of the supported frameworks (default 'sklearn').
+    framework_version
+                    A supported framework version, (default `None`,
+                    which selects the default server side)
+    metadata       User modifiable metadata. Standardised ones are:
+                    * 'description' A description of the model.
+                    * 'author' The attributed author of the model.
+                    * 'title' Used as display title in user interfaces.
+    description     Description of the model. (Deprecated: prefer `metadata.description`)
+    work_dir        Optional location of the working directory used to serialize the model.
+                    If not specified, a temporary directory is used.
+    (other)         Passed onto the underlying REST request.
         """
         with self._send_model_arguments(
                 model_name, trained_model,
