@@ -11,17 +11,37 @@ from ._decorators import (
 )
 
 
+RUNTIME_ARG = {
+    'name': 'runtime',
+    'type': 'str',
+    'description': 'Name of a supported Byoml runtime.',
+    'examples': ['byoml-sklearn-0.24']
+}
+RUNTIME_RETURN = {
+    'name': 'runtime',
+    'type': 'Dict',
+    'description': 'Representation of a supported runtime.'
+}
+RUNTIME_LIST_RETURN = {
+    'name': 'runtimes',
+    'type': 'List[Dict]',
+    'description': 'Representation of supported runtimes.'
+}
+
+
 class RuntimeResource(WaylayResource):
     """REST Resource for the 'runtime' entity of the 'byoml' service."""
 
     link_roots = {
-        'doc': '${doc_url}/api/byoml/?id='
+        'doc': '${doc_url}/api/byoml/?id=',
+        'apidoc': '${apidoc_url}/byoml.html'
     }
 
     actions = {
         'list': {
             'method': 'GET',
             'url': '/runtimes',
+            'returns': [RUNTIME_LIST_RETURN],
             'decorators': [
                 byoml_exception_decorator,
                 byoml_retry_decorator,
@@ -29,12 +49,15 @@ class RuntimeResource(WaylayResource):
             ],
             'description': 'List runtimes (framework and framework version).',
             'links': {
-                'doc': 'runtimes'
+                'doc': 'runtimes',
+                'apidoc': '',
             },
         },
         'get': {
             'method': 'GET',
             'url': '/runtimes/{}',
+            'arguments': [RUNTIME_ARG],
+            'returns': [RUNTIME_RETURN],
             'decorators': [
                 byoml_exception_decorator,
                 byoml_retry_decorator,
@@ -42,7 +65,8 @@ class RuntimeResource(WaylayResource):
             ],
             'description': 'Get a supported runtime.',
             'links': {
-                'doc': 'runtimes'
+                'doc': 'runtimes',
+                'apidoc': '',
             },
         }
     }
