@@ -1,18 +1,18 @@
 
 """REST client for the Waylay Data Service (broker)."""
 
-from waylay.service import WaylayService
+from waylay.service import WaylayRESTService
 
 from .series import SeriesResource
 from .events import EventsResource
 
 
-class DataService(WaylayService):
+class DataService(WaylayRESTService):
     """REST client for the Waylay Data Service (broker)."""
 
     config_key = 'data'
     service_key = 'data'
-    default_root_url = 'https://data.waylay.io'
+    gateway_root_path = '/data/v1'
     resource_definitions = {
         'series': SeriesResource,
         'events': EventsResource,
