@@ -10,16 +10,37 @@ DEFAULT_DECORATORS = [decorators.exception_decorator, decorators.return_body_dec
 DEFAULT_EXPORT_PAGE_SIZE = 2000
 
 
+RESOURCE_ARG = {
+    'name': 'resource_id',
+    'type': 'str',
+    'description': 'The id of a waylay resource.'
+}
+METRIC_ARG = {
+    'name': 'metric',
+    'type': 'str',
+    'description': 'The name of the metric of a resource series.'
+}
+ADDITIONAL_PARAMS_ARG = {
+    'name': 'params',
+    'type': 'dict',
+    'description': 'Additional parameters, mapped to url query parameters. See API documentation.'
+}
+
+
 class SeriesResource(WaylayResource):
     """REST Resource for the 'series' entity of the 'data' service."""
 
     link_roots = {
-        'doc': '${doc_url}/api/broker/?id='
+        'doc': '${doc_url}/api/broker/?id=',
+        'apidoc': '${apidoc_url}/broker.html'
     }
 
     actions = {
         'data': {
-            'method': 'GET', 'url': '/resources/{}/series/{}',
+            'method': 'GET', 'url': '/series/{}/{}',
+            'arguments': [
+                RESOURCE_ARG, METRIC_ARG, ADDITIONAL_PARAMS_ARG
+            ],
             'decorators': [
                 decorators.exception_decorator,
                 decorators.return_path_decorator(['series']),
@@ -30,7 +51,8 @@ class SeriesResource(WaylayResource):
             },
         },
         'list': {
-            'method': 'GET', 'url': '/resources/{}/series',
+            'method': 'GET', 'url': '/series/{}',
+            'arguments': [RESOURCE_ARG, ADDITIONAL_PARAMS_ARG],
             'decorators': [
                 decorators.default_params_decorator({'metadata': 'true'}),
                 decorators.exception_decorator,
@@ -38,34 +60,44 @@ class SeriesResource(WaylayResource):
             ],
             'description': 'Retrieve a list of series and their latest value for a given resource.',
             'links': {
-                'doc': 'metadata'
+                'doc': 'metadata',
+                'apidoc': '',
             },
         },
         'latest': {
-            'method': 'GET', 'url': '/resources/{}/series/{}/latest',
+            'method': 'GET', 'url': '/series/{}/{}/latest',
+            'arguments': [RESOURCE_ARG, METRIC_ARG],
             'decorators': [
                 decorators.exception_decorator,
                 decorators.return_path_decorator([])
             ],
             'description': 'Fetch the latest value for a series.',
             'links': {
-                'doc': 'latest-value-for-a-series'
+                'doc': 'latest-value-for-a-series',
+                'apidoc': '',
             },
         },
         'query': {
             'method': 'POST', 'url': '/series/query',
+            'arguments': [{
+                'name': 'body',
+                'type': 'Dict',
+                'description': 'A series query specification (see REST API doc).'
+            }],
             'description': 'Execute a broker query document to retrieve aggregated timeseries.',
             'decorators': [
                 decorators.exception_decorator,
                 decorators.return_path_decorator(['series'])
             ],
             'links': {
-                'doc': 'post-timeseries-query'
+                'doc': 'post-timeseries-query',
+                'apidoc': '',
             },
         },
         'export': {
             'method': 'GET',
-            'url': '/resources/{}/series/{}/raw',
+            'url': '/series/{}/{}/raw',
+            'arguments': [RESOURCE_ARG, METRIC_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'Export a single series using paging with HAL links.',
             'decorators': [
                 decorators.exception_decorator,
@@ -75,7 +107,8 @@ class SeriesResource(WaylayResource):
                 decorators.return_path_decorator(['series']),
             ],
             'links': {
-                'doc': 'getting-time-series-data'
+                'doc': 'getting-time-series-data',
+                'apidoc': '',
             },
         }
     }
@@ -89,7 +122,7 @@ class SeriesResource(WaylayResource):
     ) -> Iterator[Tuple[int, Any]]:
         """Fully export a timeseries.
 
-        Uses paging on the '/resources/{}/series/{}/raw' endpoint.
+        Uses paging on the '/series/{}/{}/raw' endpoint.
 
         Parameters
             resource_id: the resource id for the timeseries
