@@ -1,16 +1,16 @@
 """REST client for the Waylay ETL Service."""
 
-from waylay.service import WaylayService
+from waylay.service import WaylayRESTService
 
 from .import_ import ImportResource
 
 
-class ETLService(WaylayService):
+class ETLService(WaylayRESTService):
     """REST client for the Waylay ETL Service."""
 
     config_key = 'etl'
     service_key = 'etl'
-    default_root_url = 'https://etl.waylay.io'
+    gateway_root_path = '/etl/v1'
     resource_definitions = {
         'etl_import': ImportResource,
     }
