@@ -14,18 +14,14 @@ class ImportResource(WaylayResource):
     }
 
     actions = {
-        'initiate': {
-            'method': 'POST',
-            'url': '/api/etl/import',
-            'decorators': DEFAULT_DECORATORS,
-            'description': "Initiates an etl import process as specified in the request body.",
-            'links': {
-                'doc': 'etl-import-service',
-            }
-        },
         'get': {
             'method': 'GET',
-            'url': '/api/etl/import',
+            'url': '/etl/import',
+            'returns': [{
+                'name': 'body',
+                'type': 'dict',
+                'description': 'A representation of the active or last ETL import process (if any).'
+            }],
             'decorators': DEFAULT_DECORATORS,
             'description': "Retrieves the last or active etl import process.",
             'links': {
