@@ -1,6 +1,6 @@
 """REST client for the Waylay Storage Service."""
 
-from waylay.service import WaylayService
+from waylay.service import WaylayRESTService
 
 from .bucket import BucketResource
 from .object import ObjectResource, FolderResource
@@ -9,18 +9,20 @@ from .about import AboutResource
 from .subscription import SubscriptionResource
 
 
-class StorageService(WaylayService):
+class StorageService(WaylayRESTService):
     """REST client for the Waylay Storage Service."""
 
     config_key = 'storage'
     service_key = 'storage'
-    default_root_url = 'https://storage.waylay.io'
+    gateway_root_path = '/storage/v1'
+
     resource_definitions = {
         'bucket': BucketResource,
         'object': ObjectResource,
         'folder': FolderResource,
         'subscription': SubscriptionResource,
-        'about': AboutResource
+        'about': AboutResource,
+        'content': ContentTool,
     }
 
     bucket: BucketResource
@@ -28,8 +30,4 @@ class StorageService(WaylayService):
     folder: FolderResource
     subscription: SubscriptionResource
     about: AboutResource
-
-    @property
-    def content(self) -> ContentTool:
-        """Get the tool to access the content of storage objects."""
-        return ContentTool(self.object)
+    content: ContentTool
