@@ -10,8 +10,7 @@ class AboutResource(WaylayResource):
 
     link_roots = {
         'doc': '${doc_url}/api/storage/?id=',
-        'apidoc':  '${root_url}/docs#/status/',
-        'openapi': '${root_url}/openapi.json'
+        'apidoc': '${apidoc_url}/storage.html'
     }
 
     actions = {
@@ -22,8 +21,7 @@ class AboutResource(WaylayResource):
             'description': 'Application version',
             'links': {
                 'doc': 'version',
-                'apidoc': 'version__get',
-                'openapi': f"#/paths/{quote('/')}/get",
+                'apidoc': '',
             },
         },
         'status': {
@@ -33,8 +31,7 @@ class AboutResource(WaylayResource):
             'description': 'Validation and statistics on the buckets and policies for this tenant.',
             'links': {
                 'doc': 'tenant-status',
-                'apidoc': 'status_status_get',
-                'openapi': f"#/paths/{quote('/status')}/get",
+                'apidoc': '',
             },
         },
     }
