@@ -3,14 +3,25 @@ from urllib.parse import quote
 
 from waylay.service import WaylayResource, decorators
 
+BUCKET_NAME_ARG = {
+    'name': 'bucket_name',
+    'type': 'str',
+    'description': 'Name of a Waylay storage bucket.',
+    'examples': ['assets', 'public']
+}
+ADDITIONAL_PARAMS_ARG = {
+    'name': 'params',
+    'type': 'dict',
+    'description': 'Additional parameters, mapped to url query parameters. See API documentation.'
+}
+
 
 class BucketResource(WaylayResource):
     """REST Resource for the 'bucket' entity of the 'storage' service."""
 
     link_roots = {
         'doc': '${doc_url}/api/storage/?id=',
-        'apidoc':  '${root_url}/docs#/storage/',
-        'openapi': '${root_url}/openapi.json'
+        'apidoc': '${apidoc_url}/storage.html'
     }
 
     actions = {
@@ -22,8 +33,7 @@ class BucketResource(WaylayResource):
             'description': 'List available bucket aliases',
             'links': {
                 'doc': 'list-bucket',
-                'apidoc': 'list_buckets_bucket__get',
-                'openapi': f"#/paths/{quote('/bucket')}/get"
+                'apidoc': '',
             }
         },
         'get': {
@@ -31,11 +41,11 @@ class BucketResource(WaylayResource):
                 decorators.exception_decorator,
                 decorators.return_body_decorator,
             ],
+            'arguments': [BUCKET_NAME_ARG],
             'description': 'Get metadata for a specific bucket alias',
             'links': {
                 'doc': 'get-bucket',
-                'apidoc': 'get_bucket_bucket__bucket_name__get',
-                'openapi': f"#/paths/{quote('/bucket/{bucket_name}')}/get"
+                'apidoc': '',
             }
         },
     }
