@@ -11,6 +11,36 @@ from typing import Union, Optional, Dict, Iterator
 from waylay.service import WaylayResource
 from waylay.service import decorators
 
+BUCKET_NAME_ARG = {
+    'name': 'bucket_name',
+    'type': 'str',
+    'description': 'Name of a Waylay storage bucket.',
+    'examples': ['assets', 'public']
+}
+FOLDER_PATH_ARG = {
+    'name': 'path',
+    'type': 'str',
+    'description': 'The path of a folder in a bucket.',
+    'examples': ['my_project/images']
+}
+OBJECT_PATH_ARG = {
+    'name': 'path',
+    'type': 'str',
+    'description': 'The path of an object in a bucket.',
+    'examples': ['my_project/images/mouse.jpg']
+}
+PATH_PREFIX_ARG = {
+    'name': 'path',
+    'type': 'str',
+    'description': 'A path prefix for objects or folders in a bucket..',
+    'examples': ['my_project/images/mouse']
+}
+ADDITIONAL_PARAMS_ARG = {
+    'name': 'params',
+    'type': 'dict',
+    'description': 'Additional parameters, mapped to url query parameters. See API documentation.'
+}
+
 
 def parse_expiry_params(expiry: Union[str, timedelta]) -> Dict[str, int]:
     """Parse sign expiry parameters.
@@ -58,8 +88,7 @@ class FolderResource(WaylayResource):
 
     link_roots = {
         'doc': '${doc_url}/api/storage/?id=',
-        'apidoc':  '${root_url}/docs#/storage/',
-        'openapi': '${root_url}/openapi.json'
+        'apidoc':  '${apidoc_url}/storage.html',
     }
 
     actions = {
@@ -71,11 +100,11 @@ class FolderResource(WaylayResource):
                     ['objects']
                 ),
             ],
+            'arguments': [BUCKET_NAME_ARG, FOLDER_PATH_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'List objects in this folder.',
             'links': {
                 'doc': 'list-object',
-                'apidoc': 'list_or_get_objects_bucket__bucket_name___object_path__get',
-                'openapi': f"#/paths/{quote('/bucket/{bucket_name}/{object_path}')}/get"
+                'apidoc': '',
             }
         },
         'create': {
@@ -84,15 +113,18 @@ class FolderResource(WaylayResource):
                 decorators.exception_decorator,
                 decorators.return_body_decorator,
             ],
+            'arguments': [BUCKET_NAME_ARG, FOLDER_PATH_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'Create a folder.',
             'links': {
                 'doc': 'put-folder',
-                'apidoc': 'create_folder_bucket__bucket_name___object_path___put',
-                'openapi': f"#/paths/{quote('/bucket/{bucket_name}/{object_path}/')}/put"
+                'apidoc': '',
             }
         },
         'stat': {
-            'method': 'GET', 'url': '/bucket/{}/{}/?stat=true', 'decorators': [
+            'method': 'GET',
+            'url': '/bucket/{}/{}/?stat=true',
+            'arguments': [BUCKET_NAME_ARG, FOLDER_PATH_ARG, ADDITIONAL_PARAMS_ARG],
+            'decorators': [
                 _object_path_remove_path_suffix,
                 decorators.exception_decorator,
                 decorators.return_body_decorator,
@@ -100,23 +132,24 @@ class FolderResource(WaylayResource):
             'description': 'Get the details of this folder',
             'links': {
                 'doc': 'get-object',
-                'apidoc': 'list_or_get_objects_bucket__bucket_name___object_path__get',
-                'openapi': f"#/paths/{quote('/bucket/{bucket_name}/{object_path}')}/get"
+                'apidoc': '',
             }
         },
         'remove': {
-            'method': 'DELETE', 'url': '/bucket/{}/{}/', 'decorators': [
+            'method': 'DELETE',
+            'url': '/bucket/{}/{}/',
+            'decorators': [
                 _object_path_remove_path_suffix,
                 decorators.exception_decorator,
                 decorators.return_path_decorator(
                     ['_links']
                 )
             ],
+            'arguments': [BUCKET_NAME_ARG, FOLDER_PATH_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'Remove this folder',
             'links': {
                 'doc': 'delete-object-or-folder',
-                'apidoc': 'delete_object_bucket__bucket_name___object_path__delete',
-                'openapi': f"#/paths/{quote('/bucket/{bucket_name}/{object_path}')}/delete"
+                'apidoc': '',
             }
         },
     }
@@ -127,8 +160,7 @@ class ObjectResource(WaylayResource):
 
     link_roots = {
         'doc': '${doc_url}/api/storage/?id=',
-        'apidoc':  '${root_url}/docs#/storage/',
-        'openapi': '${root_url}/openapi.json'
+        'apidoc':  '${apidoc_url}/storage.html',
     }
 
     actions = {
@@ -139,11 +171,11 @@ class ObjectResource(WaylayResource):
                     ['_links', 'get_object', 'href']
                 ),
             ],
+            'arguments': [BUCKET_NAME_ARG, OBJECT_PATH_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'Create a signed http GET link for the given bucket and object path.',
             'links': {
                 'doc': 'sign_url',
-                'apidoc': 'list_or_get_objects_bucket__bucket_name___object_path__get',
-                'openapi': f"#/paths/{quote('/subscription/{bucket_name}')}/get"
+                'apidoc': '',
             }
         },
         'sign_post': {
@@ -153,11 +185,11 @@ class ObjectResource(WaylayResource):
                     ['_links', 'post_object']
                 ),
             ],
+            'arguments': [BUCKET_NAME_ARG, PATH_PREFIX_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'Create a signed http POST link for the given bucket and object path.',
             'links': {
                 'doc': 'sign_url',
-                'apidoc': 'list_or_get_objects_bucket__bucket_name___object_path__get',
-                'openapi': f"#/paths/{quote('/subscription/{bucket_name}')}/get"
+                'apidoc': '',
             }
         },
         'sign_put': {
@@ -167,11 +199,11 @@ class ObjectResource(WaylayResource):
                     ['_links', 'put_object', 'href']
                 ),
             ],
+            'arguments': [BUCKET_NAME_ARG, OBJECT_PATH_ARG, ADDITIONAL_PARAMS_ARG],
             'description':  'Create a signed http PUT link for the given bucket and object path.',
             'links': {
                 'doc': 'sign_url',
-                'apidoc': 'list_or_get_objects_bucket__bucket_name___object_path__get',
-                'openapi': f"#/paths/{quote('/subscription/{bucket_name}')}/get"
+                'apidoc': '',
             }
         },
         'stat': {
@@ -179,11 +211,11 @@ class ObjectResource(WaylayResource):
                 decorators.exception_decorator,
                 decorators.return_body_decorator,
             ],
+            'arguments': [BUCKET_NAME_ARG, OBJECT_PATH_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'Get the object metadata for the given bucket and object path.',
             'links': {
                 'doc': 'get-object',
-                'apidoc': 'list_or_get_objects_bucket__bucket_name___object_path__get',
-                'openapi': f"#/paths/{quote('/subscription/{bucket_name}')}/get"
+                'apidoc': '',
             }
         },
         'remove': {
@@ -191,11 +223,11 @@ class ObjectResource(WaylayResource):
                 decorators.exception_decorator,
                 decorators.return_body_decorator
             ],
+            'arguments': [BUCKET_NAME_ARG, OBJECT_PATH_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'Remove the object at the given bucket and object path.',
             'links': {
                 'doc': 'delete-object-or-folder',
-                'apidoc': 'delete_object_bucket__bucket_name___object_path__delete',
-                'openapi': f"#/paths/{quote('/subscription/{bucket_name}')}/get"
+                'apidoc': '',
             }
         },
         'list': {
@@ -205,13 +237,19 @@ class ObjectResource(WaylayResource):
                     ['objects']
                 ),
             ],
+            'arguments': [BUCKET_NAME_ARG, PATH_PREFIX_ARG, ADDITIONAL_PARAMS_ARG],
             'description': 'List objects in given bucket with a given path prefix.',
             'links': {
                 'doc': 'list-object',
-                'apidoc': 'list_or_get_objects_bucket__bucket_name___object_path__get',
-                'openapi': f"#/paths/{quote('/subscription/{bucket_name}')}/get"
+                'apidoc': '',
             }
         },
+        'iter_list_all': {
+            'arguments': [BUCKET_NAME_ARG, PATH_PREFIX_ARG, ADDITIONAL_PARAMS_ARG],
+            'wrapped_actions': [
+                'list'
+            ]
+        }
     }
 
     def iter_list_all(self, bucket: str, prefix: str, params: Optional[Dict] = None) -> Iterator[Dict]:
