@@ -465,6 +465,9 @@ def _open_csv(series_input: SeriesInput, **csv_format_args) -> Iterator[CSVReade
             yield from _open_csv_from_tar(series_path, **csv_format_args)
         elif archive_type == ArchiveType.TEXT:
             yield from _open_csv_file(series_path, **csv_format_args)
+        elif archive_type == ArchiveType.DIR:
+            for child_path in series_path.iterdir():
+                yield from _open_csv(child_path, **csv_format_args)
         else:
             raise Exception(f'Unsupported input file {series_path} of type {archive_type}')
 
