@@ -162,7 +162,7 @@ def iter_timeseries_dataframe(
             input_data = input_data.set_index(settings.timestamp_column)
             input_data.index.name = TIMESTAMP_COLUMN
 
-        if settings.timestamp_constructor or not(isinstance(input_data.index, pd.DatetimeIndex)):
+        if settings.timestamp_constructor or not isinstance(input_data.index, pd.DatetimeIndex):
             index_series: pd.Series = input_data.index.to_series()
             input_data = input_data.reset_index(drop=True)
             if settings.timestamp_constructor:
@@ -225,7 +225,7 @@ def iter_timeseries_dataframe(
         ])
         series_count = 1
     else:
-        column_series_iter = input_data.iteritems()
+        column_series_iter = input_data.items()
         series_count = len(input_data.columns)
     if progress and series_count > 1:
         with tqdm(total=series_count, unit_scale=True, unit_divisor=1, unit="series") as tqdm_progress:
