@@ -58,12 +58,7 @@ CSVReader = Iterator[Sequence[str]]
 CSVReaderAndResource = Tuple[CSVReader, Optional[str]]
 PathLike = Union[str, os.PathLike]
 
-
-if sys.version_info < (3, 7):  # pragma: no cover
-    import dateutil.parser
-    fromisoformat = dateutil.parser.isoparse
-else:
-    fromisoformat = datetime.fromisoformat
+fromisoformat = datetime.fromisoformat
 
 MAX_EPOCH_SECONDS = 9223000000  # '2262-04-07 16:26:40+0000'
 MAX_EPOCH_MILLIS = MAX_EPOCH_SECONDS * 1000
@@ -382,7 +377,7 @@ class TimestampFormat(str, Enum):
         parse_timestamp_auto,
         lambda t: t.isoformat(),
     )
-    value: str
+
     description: str
     example: Any
     _spec_matcher: Pattern
@@ -457,6 +452,10 @@ class TimestampFormat(str, Enum):
         timezone = self._parse_tz(tz)
         return lambda ts: formatter(ts.astimezone(timezone))
 
+    def __str__(self):
+        """Get the string representation."""
+        return self.value
+
 
 @dataclass
 class SeriesSettings:
@@ -559,7 +558,7 @@ class SeriesSettings:
                 yield Metric(name=self.metric)
             return
 
-        for metric in self.metrics:  # pylint: disable=not-an-iterable  # 3.6 issue
+        for metric in self.metrics:
             if isinstance(metric, Metric):
                 metric_spec = metric
             else:
@@ -575,7 +574,7 @@ class SeriesSettings:
                 yield Resource(id=self.resource)
             return
 
-        for resource in self.resources:  # pylint: disable=not-an-iterable  # 3.6 issue
+        for resource in self.resources:
             if isinstance(resource, Resource):
                 resource_spec = resource
             else:
@@ -809,7 +808,6 @@ CSVOutput = Union[
 class ArchiveType(str, Enum):
     """Typed enumeration of supported archive import and export types."""
 
-    value: str
     description: str
     supports_multiple_files: bool
     expected_suffixes: List[str]
@@ -846,6 +844,10 @@ class ArchiveType(str, Enum):
     TAR = ('tar', 'Tar archive of csv text files.', True, ['.tar'], ['.gz'])
     TAR_GZ = ('targz', 'Compressed Tar archive of csv text files.', True, ['.tar', '.gz'])
 
+    def __str__(self):
+        """Get the string representation."""
+        return self.value
+
     @classmethod
     def lookup(cls, value: Optional[str]) -> Optional['ArchiveType']:
         """Lookup an enum object from a str value."""
