@@ -14,11 +14,13 @@ import logging
 import pandas as pd
 
 from waylay.exceptions import WaylayError
+from waylay.service import WaylayResource
 from waylay.service.storage import StorageService
 from waylay.service.etl import ETLService
-from waylay.service.api import ApiService
+from waylay.service.resources import ResourcesService
 from waylay.service.data import DataService
-from waylay.service.analytics import AnalyticsService
+from waylay.service.queries import QueriesService
+from waylay.service._base import WaylayServiceContext
 
 from .parser.model import (
     SeriesInput,
@@ -62,6 +64,10 @@ class ResourceUpdateLevel(str, Enum):
     ID = 'id'
     ALL = 'all'
 
+    def __str__(self):
+        """Get the string representation."""
+        return self.value
+
 
 class ETLImportStatus(str, Enum):
     """The possible states of an ETL import job.
@@ -76,6 +82,10 @@ class ETLImportStatus(str, Enum):
     DONE = 'done'
     NOT_FOUND = 'not_found'
 
+    def __str__(self):
+        """Get the string representation."""
+        return self.value
+
 
 ETL_IMPORT_STATUS_MESSAGE = {
     ETLImportStatus.UPLOAD:
@@ -190,7 +200,7 @@ class ETLImportJob:
         return self.to_dataframe().to_html(escape=False)
 
 
-class TimeSeriesETLTool:
+class TimeSeriesETLTool(WaylayResource):
     """Client tool to prepare and upload or download timeseries data.
 
     Attributes:
@@ -202,22 +212,34 @@ class TimeSeriesETLTool:
             Default temporary directory used for processes initiated by this tool.
     """
 
-    def __init__(
-        self,
-        storage_service: StorageService,
-        etl_service: ETLService,
-        api_service: ApiService,
-        data_service: DataService,
-        analytics_service: AnalyticsService,
-        temp_dir: Optional[PathLike] = None
-    ):
-        """Create the timeseries etl import tool."""
-        self.storage_service = storage_service
-        self.etl_service = etl_service
-        self.api_service = api_service
-        self.data_service = data_service
-        self.analytics_service = analytics_service
-        self.temp_dir = temp_dir
+    actions: Dict[str, Any] = {
+        'prepare_import': {'wrapped_actions': []},
+        'initiate_import': {'wrapped_actions': []},
+        'list_import':  {'wrapped_actions': []},
+        'check_import':  {'wrapped_actions': []},
+        'cleanup_import':  {'wrapped_actions': []},
+        'read_import_as_csv':  {'wrapped_actions': []},
+        'read_import_as_dataframe':  {'wrapped_actions': []},
+        'list_import_resources':  {'wrapped_actions': []},
+        'update_resources':  {'wrapped_actions': []},
+        'export_series_as_csv':  {'wrapped_actions': []},
+        'update_query':  {'wrapped_actions': []},
+    }
+
+    storage_service: StorageService
+    etl_service: ETLService
+    resources_service: ResourcesService
+    query_service: QueriesService
+    data_service: DataService
+    temp_dir: Optional[PathLike] = None
+
+    def set_context(self, service_context: WaylayServiceContext):
+        """Configure this tool with a service context."""
+        self.storage_service = service_context.require(StorageService)
+        self.etl_service = service_context.require(ETLService)
+        self.resources_service = service_context.require(ResourcesService)
+        self.data_service = service_context.require(DataService)
+        self.query_service = service_context.require(QueriesService)
 
     def prepare_import(
         self,
@@ -230,23 +252,24 @@ class TimeSeriesETLTool:
     ) -> WaylayETLSeriesImport:
         """Convert an input data set to a locally stored timeseries file.
 
-        This created file can be ingested by the waylay system as timeseries data.
-        Args:
-            series: A supported CSV of pandas Dataframe input source.
-            name:
-                A name for the upload job, will be used in naming the ETL file.
-                (default: 'import-{timestamp}')
-            temp_dir:
-                The local storage location to use in preparing the ETL file.
-                (default: a system generated temp file with prefix 'etl-import')
-            settings:
-                A full specification object for the data conversion. Alternatively,
-                attributes of this `SeriesSettings` object can be specified as keyword
-                argument.
-            progress:
-                Write a progress bar for the conversion to standard output.
-            **settings_args:
-                Any attribute of a `SeriesSettings` object. See `settings` above.
+This created file can be ingested by the waylay system as timeseries data.
+
+Arguments:
+    series: A supported CSV or pandas Dataframe input source.
+    name:
+        A name for the upload job, will be used in naming the ETL file.
+        (default: 'import-{timestamp}')
+    temp_dir:
+        The local storage location to use in preparing the ETL file.
+        (default: a system generated temp file with prefix 'etl-import')
+    settings:
+        A full specification object for the data conversion. Alternatively,
+        attributes of this `SeriesSettings` object can be specified as keyword
+        argument.
+    progress:
+        Write a progress bar for the conversion to standard output.
+    **settings_args:
+        Any attribute of a `SeriesSettings` object. See `settings` above.
         """
         etl_file = ETLFile(temp_dir or self.temp_dir, name)
         etl_import = prepare_etl_import(*series, import_file=etl_file, settings=settings, **settings_args)
@@ -260,10 +283,10 @@ class TimeSeriesETLTool:
     ) -> WaylayETLSeriesImport:
         """Upload a prepared timeseries file to the etl-import ingestion bucket.
 
-        Args:
-            etl_import:
-                A reference object to the input source and converted etl file, as
-                produced by `prepare_import`.
+Arguments:
+    etl_import:
+        A reference object to the input source and converted etl file, as
+        produced by `prepare_import`.
         """
         self.storage_service.content.put(
             etl_import.storage_bucket,
@@ -286,19 +309,19 @@ class TimeSeriesETLTool:
     ) -> List[ETLImportJob]:
         """List all imports in all states on the `etl-import` bucket.
 
-        This queries both the content of the `etl-import` bucket,
-        and the current or last job held by the ETL Service.
+This queries both the content of the `etl-import` bucket,
+and the current or last job held by the ETL Service.
 
-        Args:
-            name_filter:
-                A query filter on the name of the etl import files to consider.
-            status_filter:
-                A filter on the status of the import jobs, a list of strings
-                as enumerated in `ETLImportStatus`
+Arguments:
+    name_filter:
+        A query filter on the name of the etl import files to consider.
+    status_filter:
+        A filter on the status of the import jobs, a list of strings
+        as enumerated in `ETLImportStatus`
 
-        Returns:
-            A list of 'ETLImportJob' objects that represent the processing status
-            of an ETL import job.
+Returns:
+    A list of 'ETLImportJob' objects that represent the processing status
+    of an ETL import job.
         """
         # query storage objects in 'etl-import' bucket
         if name_filter:
@@ -353,15 +376,15 @@ class TimeSeriesETLTool:
     ) -> ETLImportJob:
         """Validate the status of an import process started by this tool.
 
-        Args:
-            etl_import:
-                Either a `WaylayETLSeriesImport`, representing a prepared import task,
-                as produced by `initiate_import`,
-                or an `ETLImportJob`, representing the status of that task,
-                as returned by `list_import`, `check_import`
-                or a the name of an import job.
-        Returns:
-            An object representing the current status of the ETL import job.
+Arguments:
+    etl_import:
+        Either a `WaylayETLSeriesImport`, representing a prepared import task,
+        as produced by `initiate_import`,
+        or an `ETLImportJob`, representing the status of that task,
+        as returned by `list_import`, `check_import`
+        or a the name of an import job.
+Returns:
+    An object representing the current status of the ETL import job.
         """
         if isinstance(etl_import, str):
             import_name = etl_import
@@ -416,18 +439,18 @@ class TimeSeriesETLTool:
     ) -> ETLImportJob:
         """Clean up the server storage for an import task.
 
-        Args:
-            etl_import:
-                Either a `WaylayETLSeriesImport`, representing a prepared import task,
-                as produced by `initiate_import`,
-                or an `ETLImportJob`, representing the status of that task,
-                as returned by `list_import`, `check_import`.
-            force:
-                If true, delete storage even if the import job is reported
-                to be running or not existing.
+Arguments:
+    etl_import:
+        Either a `WaylayETLSeriesImport`, representing a prepared import task,
+        as produced by `initiate_import`,
+        or an `ETLImportJob`, representing the status of that task,
+        as returned by `list_import`, `check_import`.
+    force:
+        If true, delete storage even if the import job is reported
+        to be running or not existing.
 
-        Returns:
-            An object representing the current status of the ETL import job.
+Returns:
+    An object representing the current status of the ETL import job.
 
         """
         etl_import_job = self.check_import(etl_import)
@@ -457,20 +480,20 @@ class TimeSeriesETLTool:
     ) -> Iterator[CSVReader]:
         """Read an etl import file as a csv stream.
 
-        This returns a context manager that provides an iterator
-        of csv rows (`Iterator[Sequence[str]]`):
+This returns a context manager that provides an iterator
+of csv rows (`Iterator[Sequence[str]]`):
 
-            with etl_tool.read_import_as_csv(etl_import) as csv_data:
-                for csv_line in csv_data:
-                    print("|".join(csv_line))
+    with etl_tool.read_import_as_csv(etl_import) as csv_data:
+        for csv_line in csv_data:
+            print("|".join(csv_line))
 
-        Args:
-            etl_import:
-                The object representing the converted ETL import file,
-                as produced by `prepare_import`.
+Arguments:
+    etl_import:
+        The object representing the converted ETL import file,
+        as produced by `prepare_import`.
 
-        Returns:
-            A context manager providing an iterator of string records.
+Returns:
+    A context manager providing an iterator of string records.
 
         """
         with read_etl_import_as_stream(etl_import) as csv_iterator:
@@ -479,18 +502,18 @@ class TimeSeriesETLTool:
     def read_import_as_dataframe(self, etl_import: WaylayETLSeriesImport) -> pd.DataFrame:
         """Read an etl import file as pandas dataframe.
 
-        Args:
-            etl_import:
-                The object representing the converted ETL import file,
-                as produced by `prepare_import`.
+Arguments:
+    etl_import:
+        The object representing the converted ETL import file,
+        as produced by `prepare_import`.
 
-        Returns:
-            A pandas Dataframe containing the import data.
-            Each series is a seperate column. Column headers
-            contain a `resource` and `metric` reference.
-            When the input specification of the `etl_import` contains
-            a `metrics` object with a `value_type` or `value_parser` attribute,
-            the corresponding csv series is converted to that data type.
+Returns:
+    A pandas Dataframe containing the import data.
+    Each series is a seperate column. Column headers
+    contain a `resource` and `metric` reference.
+    When the input specification of the `etl_import` contains
+    a `metrics` object with a `value_type` or `value_parser` attribute,
+    the corresponding csv series is converted to that data type.
         """
         with read_etl_import(etl_import) as series_iterator:
             return dataframe_from_iterator(series_iterator)
@@ -501,14 +524,14 @@ class TimeSeriesETLTool:
     ) -> List[Resource]:
         """List resource and metric metadata contained in an ETL import file.
 
-        Args:
-            etl_import:
-                The object representing the converted ETL import file,
-                as produced by `prepare_import`.
+Arguments:
+    etl_import:
+        The object representing the converted ETL import file,
+        as produced by `prepare_import`.
 
-        Returns:
-            A list of `Resource` metadata objects describing the
-            content of the import file.
+Returns:
+    A list of `Resource` metadata objects describing the
+    content of the import file.
         """
         with read_etl_import(etl_import) as series_iterator:
             return list_resources(etl_import.settings, series_iterator)
@@ -520,23 +543,23 @@ class TimeSeriesETLTool:
     ) -> List[Resource]:
         """Create or update the Waylay Resources for the timeseries in this dataset.
 
-        Args:
-            etl_import:
-                The object representing the converted ETL import file,
-                as produced by `prepare_import`.
+Arguments:
+    etl_import:
+        The object representing the converted ETL import file,
+        as produced by `prepare_import`.
 
-        Returns:
-            A list of `Resource` metadata objects describing the
-            content of the import file, and for which metadata has been updated
-            to the waylay system
+Returns:
+    A list of `Resource` metadata objects describing the
+    content of the import file, and for which metadata has been updated
+    to the waylay system
         """
         resources = self.list_import_resources(etl_import)
         for resource in resources:
             if resource_update_level == ResourceUpdateLevel.ID:
-                self.api_service.resource.update(resource.id, body={})
+                self.resources_service.resource.update(resource.id, body={})
 
             if resource_update_level == ResourceUpdateLevel.ALL:
-                self.api_service.resource.update(resource.id, body=resource.to_dict())
+                self.resources_service.resource.update(resource.id, body=resource.to_dict())
         return resources
 
     def update_query(
@@ -547,21 +570,21 @@ class TimeSeriesETLTool:
     ) -> Any:
         """Create or update a waylay query containing all the series defined in this import.
 
-        The name of the import will be used as query name.
-        Args:
-            etl_import:
-                The object representing the converted ETL import file,
-                as produced by `prepare_import`.
-            name:
-                The name of the query. Defaults to the prefix name of
-                the etl_import argument (`etl_import.import_file.prefix`).
-            query_params:
-                Any additional query params (like `from`, `util`, `freq`, `aggregation`, ...)
-                to be used in the query
+The name of the import will be used as query name.
+Arguments:
+    etl_import:
+        The object representing the converted ETL import file,
+        as produced by `prepare_import`.
+    name:
+        The name of the query. Defaults to the prefix name of
+        the etl_import argument (`etl_import.import_file.prefix`).
+    query_params:
+        Any additional query params (like `from`, `util`, `freq`, `aggregation`, ...)
+        to be used in the query
 
-        Returns:
-            The result of a `analytics.query.replace()` SDK call that
-            updated or created the query with the name of the import.
+Returns:
+    The result of a `queries.query.replace()` SDK call that
+    updated or created the query with the name of the import.
         """
         query_name = name or etl_import.import_file.prefix
         resources = self.list_import_resources(etl_import)
@@ -581,7 +604,13 @@ class TimeSeriesETLTool:
             ]
         }
         query.update(query_params)
-        return self.analytics_service.query.replace(query_name, body={'query': query})
+        return self.query_service.query.replace(query_name, body={
+            'query': query,
+            'meta': {
+                'description': 'Generated by `timeseries.etl_tool.update_query` (python SDK), '
+                f'for etl_import via {etl_import.storage_object_name}.'
+            }
+        })
 
     def export_series_as_csv(
         self,
@@ -592,7 +621,20 @@ class TimeSeriesETLTool:
         timestamp_column: Optional[str] = 'timestamp',
         **settings_args: Any,
     ):
-        """Export a number of series from the times series database."""
+        """Export a number of series from the times series database.
+
+    Arguments:
+        output:
+            The object to which the csv lines will be written. Can be a file path, stream, etc.
+        archive_type:
+            Optional archive type.
+        progress:
+            Optional boolean to write a progress bar for the export.
+        settings:
+            Optional series settings.
+        timestamp_column:
+            Optional name for timestamp column. Defaults to 'timestamp'. Set to None if not wanted.
+        """
         export_settings = settings or SeriesSettings()
         export_settings = replace(export_settings, **settings_args)
         # set timestamp column (default `timestamp`) unless explicitely set to None
