@@ -14,12 +14,12 @@ class UtilService(WaylayService):
 
     info: InfoTool
 
+    resource_definitions = {
+        'info': InfoTool
+    }
+
     def configure(self, config: WaylayConfig, context: WaylayServiceContext) -> 'UtilService':
         """Configure endpoints and authentication with given config."""
-        self.config = config
-        self.info = InfoTool(context)
-        return self.reconfigure()
-
-    def reconfigure(self) -> 'UtilService':
-        """Reconfigure this service after a configuration change."""
+        super().configure(config, context)
+        self.info.set_context(context)
         return self
